@@ -49,9 +49,9 @@ void                  gdk_init                            (gint           *argc,
 GDK_AVAILABLE_IN_ALL
 gboolean              gdk_init_check                      (gint           *argc,
                                                            gchar        ***argv);
-GDK_AVAILABLE_IN_ALL
+GDK_DEPRECATED_IN_3_16
 void                  gdk_add_option_entries_libgtk_only  (GOptionGroup   *group);
-GDK_AVAILABLE_IN_ALL
+GDK_DEPRECATED_IN_3_16
 void                  gdk_pre_parse_libgtk_only           (void);
 
 GDK_AVAILABLE_IN_ALL
@@ -95,8 +95,6 @@ GdkGrabStatus gdk_keyboard_grab      (GdkWindow    *window,
                                       guint32       time_);
 #endif /* GDK_MULTIDEVICE_SAFE */
 
-#ifndef GDK_MULTIHEAD_SAFE
-
 #ifndef GDK_MULTIDEVICE_SAFE
 GDK_DEPRECATED_IN_3_0_FOR(gdk_device_ungrab)
 void          gdk_pointer_ungrab     (guint32       time_);
@@ -122,8 +120,6 @@ void gdk_set_double_click_time (guint msec);
 GDK_AVAILABLE_IN_ALL
 void gdk_beep (void);
 
-#endif /* GDK_MULTIHEAD_SAFE */
-
 GDK_AVAILABLE_IN_ALL
 void gdk_flush (void);
 
