@@ -49,6 +49,7 @@ _gdk_win32_gl_context_dispose (GObject *gobject)
   GdkGLContext *context = GDK_GL_CONTEXT (gobject);
   GdkWin32GLContext *context_win32 = GDK_WIN32_GL_CONTEXT (gobject);
   GdkWin32Display *display_win32 = GDK_WIN32_DISPLAY (gdk_gl_context_get_display (context));
+  GdkWindow *window = gdk_gl_context_get_window (context);
 
   if (context_win32->hglrc != NULL)
     {
@@ -63,6 +64,20 @@ _gdk_win32_gl_context_dispose (GObject *gobject)
       ReleaseDC (display_win32->gl_hwnd, context_win32->gl_hdc);
     }
 
+  if (window != NULL && window->impl != NULL)
+    {
+      GdkWindowImplWin32 *impl = GDK_WINDOW_IMPL_WIN32 (window->impl);
+
+      if (impl->suppress_layered > 0)
+        impl->suppress_layered--;
+
+      /* If we don't have any window that forces layered windows off,
+       * trigger update_style_bits() to enable layered windows again
+       */
+      if (impl->suppress_layered == 0)
+        _gdk_win32_window_update_style_bits (window);
+    }
+
   G_OBJECT_CLASS (gdk_win32_gl_context_parent_class)->dispose (gobject);
 }
 
@@ -455,6 +470,9 @@ _gdk_win32_gl_context_realize (GdkGLContext *context,
   gint glver_major = 0;
   gint glver_minor = 0;
 
+  GdkWindow *window = gdk_gl_context_get_window (context);
+  GdkWindowImplWin32 *impl = GDK_WINDOW_IMPL_WIN32 (window->impl);
+
   if (!_set_pixformat_for_hdc (context_win32->gl_hdc,
                                &pixel_format,
                                context_win32->need_alpha_bits))
@@ -500,6 +518,17 @@ _gdk_win32_gl_context_realize (GdkGLContext *context,
 
   context_win32->hglrc = hglrc;
 
+  /* OpenGL does not work with WS_EX_LAYERED enabled, so we need to
+   * disable WS_EX_LAYERED when we acquire a valid HGLRC
+   */
+  impl->suppress_layered++;
+
+  /* if this is the first time a GL context is acquired for the window,
+   * disable layered windows by triggering update_style_bits()
+   */
+  if (impl->suppress_layered == 1)
+    _gdk_win32_window_update_style_bits (window);
+
   return TRUE;
 }
 
